@@ -1,9 +1,12 @@
-from flask import jsonify, stream_with_context, Response
+from flask import jsonify
 from . import cache
 from .dm import DataManager
+from .dm.file_data_adapter import data_adapter
 from flask_socketio import SocketIO
+from pathlib import Path
 import codecs
 import json
+import imp
 import os
 from lyrebird import application as app
 from lyrebird.log import get_logger
@@ -19,6 +22,9 @@ Mock server context
 logger = get_logger()
 
 
+class DataManagerInitException(Exception):
+    pass
+
 class Mode:
     NORMAL = 'normal'
     RECORD = 'record'
@@ -67,11 +73,10 @@ class Application:
     @conf.setter
     def conf(self, _conf):
         self._conf = _conf
+
         if _conf.get('mock.data'):
-            try:
-                self.data_manager.set_root(_conf.get('mock.data'))
-            except Exception:
-                logger.error(f'Set mock data root path failed.\n{traceback.format_exc()}')
+            self.init_datamanager(_conf.get('mock.data'))
+
         if _conf.get('mock.mode') == MockMode.MULTIPLE:
             self.is_diff_mode = MockMode.MULTIPLE
 
@@ -84,6 +89,24 @@ class Application:
                 self.selected_filter = f
                 break
 
+    def init_datamanager(self, uri):
+        adapter_cls = data_adapter
+
+        path = Path(uri).expanduser().absolute()
+
+        if path.exists() and path.is_file():
+            logger.warning(f'Loading custom data-adapter from {str(path)} .')
+            try:
+                adapter_module = imp.load_source(path.stem, str(path))
+                adapter_cls = adapter_module.data_adapter
+            except Exception:
+                logger.error(f'Loading custom data-adapter from {str(path)} failed!\n{traceback.format_exc()}')
+                raise DataManagerInitException
+        else:
+            logger.warning(f'Loading file data-adapter from {str(path)} .')
+            self.data_manager.set_adapter(adapter_cls)
+            self.data_manager.set_root(uri)
+
     def save(self):
         DEFAULT_CONF = os.path.join(
             os.path.join(os.path.expanduser('~'), '.lyrebird'), 'conf.json')
@@ -122,10 +145,6 @@ def make_fail_response(msg, code=3000, **kwargs):
     return jsonify(fail_resp)
 
 
-def make_streamed_response(generator, code=200, mimetype='application/json'):
-    return Response(stream_with_context(generator()), mimetype=mimetype, status=code)
-
-
 def emit(event, *args, **kwargs):
     now = time.time()
     last_push_time = last_emit_time.get(event, 0)
